@@ -22,8 +22,8 @@ from systemID.ClassesGeneral.ClassSystem import ContinuousNonlinearSystem
 class DuffingOscillatorDynamics:
     """
     Dynamics
-    x1' = x2
-    x2' = -delta*x2 - alpha*x1 - beta*x1^3 + u
+    x1' = x2 + u1
+    x2' = -delta*x2 - alpha*x1 - beta*x1^3 + u2
     """
 
     def __init__(self, delta, alpha, beta, **kwargs):
