@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2023 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 24
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -17,6 +17,25 @@ from systemID.ClassesGeneral.ClassSignal import DiscreteSignal
 
 
 def prediction(nominal_reference, system_reference, nominal, system, input_signal, starting_step, **kwargs):
+    """
+    Purpose:
+
+
+    Parameters:
+        -
+
+    Returns:
+        -
+
+    Imports:
+        -
+
+    Description:
+
+
+    See Also:
+        -
+    """
 
     # Get general parameters of the system
     state_dimension = system.state_dimension
@@ -99,7 +118,7 @@ def prediction(nominal_reference, system_reference, nominal, system, input_signa
 
 
 
-        # Building output signal
+        # Building output signals
         output_signal_predicted = DiscreteSignal(output_dimension, 'Output Signal Predicted', input_signal.total_time, input_signal.frequency, signal_shape='External', data=y)
 
 
