@@ -1,12 +1,14 @@
 from .augment_signals import *
+from .continuous_to_discrete import *
 from .eigensystem_realization_algorithm import *
 from .eigensystem_realization_algorithm_from_initial_condition_response import *
 from .eigensystem_realization_algorithm_with_data_correlation import *
 from .eigensystem_realization_algorithm_with_data_correlation_from_initial_condition_response import *
+from .interpolate import *
 from .mac_and_msv import *
 from .markov_parameters_from_observer_markov_parameters import *
 from .moments_propagation import *
-from .normalize import *
+from .observability_matrix import *
 from .observer_gain_markov_parameters_from_observer_markov_parameters import *
 from .observer_kalman_identification_algorithm import *
 from .observer_kalman_identification_algorithm_with_observer import *
@@ -14,6 +16,8 @@ from .polynomial_basis_functions import *
 from .polynomial_index import *
 from .propagate import *
 from .runge_kutta_45 import *
+from .scaling import *
+from .sparse_representation_1st_order import sparse_representation_1st_order
 from .state_transition_tensor_propagation import *
 from .time_invariant_koopman_operator import *
 from .time_varying_eigensystem_realization_algorithm import *
