@@ -12,7 +12,7 @@ import scipy.linalg as LA
 
 from systemID.functions.time_varying_eigensystem_realization_algorithm_from_initial_condition_response import time_varying_eigensystem_realization_algorithm_from_initial_condition_response
 
-def time_varying_eigensystem_realization_algorithm(hki, D, frequency, state_dimension, p, q, **kwargs):
+def time_varying_eigensystem_realization_algorithm(hki, D, free_response_signals, state_dimension, p, q, **kwargs):
     """
     Purpose:
 
@@ -59,8 +59,8 @@ def time_varying_eigensystem_realization_algorithm(hki, D, frequency, state_dime
     Sigma = []
 
     # Compute first few time steps using free response
-    free_response_signals = kwargs.get('free_response_signals', [])
     number_experiments = len(free_response_signals)
+    frequency = free_response_signals[0].frequency
 
 
     # First Hpq1
@@ -123,33 +123,32 @@ def time_varying_eigensystem_realization_algorithm(hki, D, frequency, state_dime
         (R1, sigma1, St1) = (R2, sigma2, St2)
 
 
-    X0_tvera_ic = 'N/A'
     # Calculating first q A, B, C - Free Response
-    if number_experiments > 0:
-        _, _, Ok_tvera_ic, Ok1_tvera_ic, Sigma_tvera_ic, X0_tvera_ic, A_id_tvera_ic, C_id_tvera_ic, MAC_tvera_ic, MSV_tvera_ic, Y = time_varying_eigensystem_realization_algorithm_from_initial_condition_response(free_response_signals, state_dimension, p, show_progress=show_progress, mac_msv=mac_msv, max_time_step=q)
 
-        A_id[:, :, 0:q] = A_id_tvera_ic[:, :, 0:q]
-        C_id[:, :, 0:q] = C_id_tvera_ic[:, :, 0:q]
-        Ok[:, :, 0:q] = Ok_tvera_ic[:, :, 0:q]
-        Ok1[:, :, 0:q] = Ok1_tvera_ic[:, :, 0:q]
+    _, _, Ok_tvera_ic, Ok1_tvera_ic, Sigma_tvera_ic, X0_tvera_ic, A_id_tvera_ic, C_id_tvera_ic, MAC_tvera_ic, MSV_tvera_ic, Y = time_varying_eigensystem_realization_algorithm_from_initial_condition_response(free_response_signals, state_dimension, p, show_progress=show_progress, mac_msv=mac_msv, max_time_step=q)
 
-        Sigma = Sigma + Sigma_tvera_ic
+    A_id[:, :, 0:q] = A_id_tvera_ic[:, :, 0:q]
+    C_id[:, :, 0:q] = C_id_tvera_ic[:, :, 0:q]
+    Ok[:, :, 0:q] = Ok_tvera_ic[:, :, 0:q]
+    Ok1[:, :, 0:q] = Ok1_tvera_ic[:, :, 0:q]
 
-        for k in range(q):
-            # Calculating corresponding Hp1
-            Hp1 = hki[k * output_dimension:(k + p) * output_dimension, k*input_dimension:(k + 1) * input_dimension]
+    Sigma = Sigma + Sigma_tvera_ic
 
-            # Identified matrices
-            if apply_transformation:
-                Tkp1 = np.matmul(LA.pinv(Ok[:, :, q]), Ok1[:, :, k])
-                Tk = np.matmul(LA.pinv(Ok[:, :, q]), Ok[:, :, k])
+    for k in range(q):
+        # Calculating corresponding Hp1
+        Hp1 = hki[k * output_dimension:(k + p) * output_dimension, k*input_dimension:(k + 1) * input_dimension]
 
-                A_id[:, :, k] = np.matmul(Tkp1, np.matmul(A_id[:, :, k], LA.pinv(Tk)))
-                B_id[:, :, k] = np.matmul(Tkp1, np.matmul(LA.pinv(Ok1[:, :, k]), Hp1))
-                C_id[:, :, k] = np.matmul(C_id[:, :, k], LA.pinv(Tk))
+        # Identified matrices
+        if apply_transformation:
+            Tkp1 = np.matmul(LA.pinv(Ok[:, :, q]), Ok1[:, :, k])
+            Tk = np.matmul(LA.pinv(Ok[:, :, q]), Ok[:, :, k])
 
-            else:
-                B_id[:, :, k] = np.matmul(LA.pinv(Ok1[:, :, k]), Hp1)
+            A_id[:, :, k] = np.matmul(Tkp1, np.matmul(A_id[:, :, k], LA.pinv(Tk)))
+            B_id[:, :, k] = np.matmul(Tkp1, np.matmul(LA.pinv(Ok1[:, :, k]), Hp1))
+            C_id[:, :, k] = np.matmul(C_id[:, :, k], LA.pinv(Tk))
+
+        else:
+            B_id[:, :, k] = np.matmul(LA.pinv(Ok1[:, :, k]), Hp1)
 
 
     # Create corresponding functions
